@@ -1,10 +1,13 @@
+pub mod args;
 mod errors;
+mod generated_styles;
 mod goban;
 mod goban_range;
 mod goban_style;
 mod make_svg;
 
 pub use errors::GobanSVGError;
+pub use generated_styles::GENERATED_STYLES;
 pub use goban::{Goban, NodeDescription, Stone, StoneColor};
 pub use goban_range::GobanRange;
 pub use goban_style::GobanStyle;
