@@ -1,9 +1,10 @@
-mod args;
 mod lib;
 
+use minidom::Element;
 use std::error::Error;
 use std::path::Path;
-use svg::node::element::SVG;
+
+use lib::args;
 
 fn main() {
     let args: Vec<String> = std::env::args().collect();
@@ -53,30 +54,36 @@ fn read_input<P: AsRef<Path>>(infile: Option<P>) -> Result<String, Box<dyn Error
     Ok(input)
 }
 
-fn write_output<P: AsRef<Path>>(svg: &SVG, outfile: Option<P>) -> Result<(), Box<dyn Error>> {
+fn write_output<P: AsRef<Path>>(svg: &Element, outfile: Option<P>) -> Result<(), Box<dyn Error>> {
     match outfile {
-        Some(filename) => write_to_file(filename.as_ref(), svg),
-        None => svg::write(std::io::stdout(), svg).map_err(|e| e.into()),
+        Some(filename) => write_to_file(filename.as_ref(), svg)?,
+        None => svg.write_to(&mut std::io::stdout())?,
     }
+    Ok(())
 }
 
-fn write_to_file(outfile: &Path, document: &SVG) -> Result<(), Box<dyn Error>> {
+fn write_to_file(outfile: &Path, svg: &Element) -> Result<(), Box<dyn Error>> {
     match outfile.extension().and_then(std::ffi::OsStr::to_str) {
-        Some("svg") => svg::save(outfile, document)?,
-        Some("png") => save_png(outfile, document)?,
+        Some("svg") => {
+            let mut file = std::fs::File::create(outfile)?;
+            svg.write_to(&mut file)?;
+        }
+        Some("png") => save_png(outfile, svg)?,
         _ => return Err(SgfRenderError::UnsupportedFileExtension.into()),
     }
     Ok(())
 }
 
 #[cfg(feature = "png")]
-fn save_png(outfile: &Path, document: &SVG) -> Result<(), Box<dyn Error>> {
-    let s = document.to_string();
+fn save_png(outfile: &Path, svg: &Element) -> Result<(), Box<dyn Error>> {
+    let mut buffer: Vec<u8> = vec![];
+    svg.write_to(&mut buffer)?;
+    let s = std::str::from_utf8(&buffer)?;
     let mut fontdb = usvg::fontdb::Database::new();
     let font_data = include_bytes!("../resources/Roboto-Bold.ttf").to_vec();
     fontdb.load_font_data(font_data);
     let tree = usvg::Tree::from_str(
-        &s,
+        s,
         &usvg::Options {
             fontdb,
             ..usvg::Options::default()
